@@ -68,22 +68,22 @@ bool BoardLayout::saveBoardLayout(const QString & where) const
     }
 
     QByteArray tmp = layoutMagic1_1.toUtf8();
-    if (f.write(tmp, tmp.length()) == -1) {
+    if (f.write(tmp) == -1) {
         return false;
     }
 
     tmp = QStringLiteral("\nw%1").arg(m_width).toUtf8();
-    if (f.write(tmp, tmp.length()) == -1) {
+    if (f.write(tmp) == -1) {
         return false;
     }
 
     tmp = QStringLiteral("\nh%1").arg(m_height).toUtf8();
-    if (f.write(tmp, tmp.length()) == -1) {
+    if (f.write(tmp) == -1) {
         return false;
     }
 
     tmp = QStringLiteral("\nd%1").arg(m_depth).toUtf8();
-    if (f.write(tmp, tmp.length()) == -1) {
+    if (f.write(tmp) == -1) {
         return false;
     }
 
@@ -134,7 +134,7 @@ bool BoardLayout::loadBoardLayout_10(const QString & from)
 
         while (!t.atEnd()) {
             s = t.readLine();
-            if (s[0] == '#') {
+            if (s[0] == QLatin1Char('#')) {
                 continue;
             }
             all += s;
@@ -180,18 +180,18 @@ bool BoardLayout::loadBoardLayout(const QString & from)
 
         while (!t.atEnd()) {
             s = t.readLine();
-            if (s[0] == '#') {
+            if (s[0] == QLatin1Char('#')) {
                 continue;
             }
-            if (s[0] == 'w') {
+            if (s[0] == QLatin1Char('w')) {
                 m_width = s.midRef(1).toInt();
                 continue;
             }
-            if (s[0] == 'h') {
+            if (s[0] == QLatin1Char('h')) {
                 m_height = s.midRef(1).toInt();
                 continue;
             }
-            if (s[0] == 'd') {
+            if (s[0] == QLatin1Char('d')) {
                 m_depth = s.midRef(1).toInt();
                 continue;
             }
@@ -237,6 +237,7 @@ void BoardLayout::initialiseBoard()
         switch (c) {
             case static_cast<UCHAR>('1'):
                 ++m_maxTileNum;
+                Q_FALLTHROUGH();
             case static_cast<UCHAR>('2'):
             case static_cast<UCHAR>('3'):
             case static_cast<UCHAR>('4'):
